InitDataSources class

Mixed-in types

Constructors

InitDataSources()

Properties

collection String
The name of the collection in Firestore.
getter/setter pairoverride-getter
enableLogging bool
Flag indicating whether logging is enabled.
no setterinherited
forTesting bool
Flag indicating whether the operations are for testing purposes.
getter/setter pairoverride-getter
hashCode int
The hash code for this object.
no setterinherited
logger → Logger?
Optional logger instance for logging operations.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add({required Map<String, dynamic> data}) Future<void>
inherited
delete({required String documentID}) Future<void>
inherited
deleteDocument({required String documentId}) Future<void>
Deletes a document by its ID.
inherited
docById({required String docId}) Future<DocumentSnapshot<Object?>>
Deprecated methods for backward compatibility.
inherited
fetchAll() Future<List>
inherited
fetchAllDocuments() Future<List<Map<String, dynamic>>>
Fetches all documents in the collection.
inherited
fetchDocumentById({required String docId}) Future<DocumentSnapshot<Object?>>
Fetches a document by its ID.
inherited
isExist({required String documentId}) Future<bool>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveDocument({required Map<String, dynamic> data}) Future<void>
Adds or updates a document.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited