ModelExample class

Annotations
  • @freezed

Constructors

ModelExample({String? id, String? email, String? fullName})
const
factory
ModelExample.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → $ModelExampleCopyWith<ModelExample>
Create a copy of ModelExample with the given fields replaced by the non-null parameter values.
no setterinherited
email String?
no setterinherited
fullName String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ModelExample to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited