ExistenceException class

Exception thrown when a document existence check fails or encounters an error.

Implemented types

Constructors

ExistenceException({required String exceptionValue})
Creates an ExistenceException with the given error message.

Properties

exception String
Retrieves the exception message.
no setter
exceptionValue String
The error message describing the exception.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited