Log extension

Extension on Object to add convenient logging functionality.

This extension provides a quick way to log the string representation of any object to the Dart developer console without importing the dev tools directly.

Example:

'Hello World'.log();  // Logs: Hello World
42.log();             // Logs: 42
[1, 2, 3].log();      // Logs: [1, 2, 3]
on

Methods

log() → void

Available on Object, provided by the Log extension

Logs the string representation of this object to the developer console.