Path extension
Extension on String to get a Firestore collection reference.
This extension provides a convenient way to access Firestore collections.
When forTesting is true, it uses a fake Firestore instance for unit testing.
Otherwise, it uses the real Firebase Firestore instance.
- on