log method
void
log()
Logs the string representation of this object to the developer console.
Uses dart:developer's log function to write output that can be viewed in the Flutter debug console or IDE debugger.
Implementation
void log() => devtools.log(toString());